from config import config
from flask import Flask
from flask_login import LoginManager
from flask_mail import Mail
from flask_paranoid import Paranoid
from flask_socketio import SocketIO
from flask_sqlalchemy import SQLAlchemy
import flask_assets


assets = flask_assets.Environment()
db = SQLAlchemy()
login_manager = LoginManager()
login_manager.login_view = 'auth.login'
mail = Mail()
paranoid = Paranoid()
paranoid.redirect_view = '/'
socketio = SocketIO()


def create_app(config_name):
    app = Flask(__name__)
    app.config.from_object(config[config_name])

    assets.init_app(app)
    config[config_name].init_app(app)
    db.init_app(app)
    login_manager.init_app(app)
    mail.init_app(app)
    paranoid.init_app(app)
    socketio.init_app(
        app, message_queue=app.config['NOPAQUE_SOCKETIO_MESSAGE_QUEUE_URI'])

    from .events import socketio as socketio_events
    from .events import sqlalchemy as sqlalchemy_events

    from .admin import bp as admin_blueprint
    app.register_blueprint(admin_blueprint, url_prefix='/admin')

    from .api import bp as api_blueprint
    app.register_blueprint(api_blueprint, url_prefix='/api')

    from .auth import bp as auth_blueprint
    app.register_blueprint(auth_blueprint, url_prefix='/auth')

    from .corpora import bp as corpora_blueprint
    app.register_blueprint(corpora_blueprint, url_prefix='/corpora')

    from .errors import bp as errors_blueprint
    app.register_blueprint(errors_blueprint)

    from .jobs import bp as jobs_blueprint
    app.register_blueprint(jobs_blueprint, url_prefix='/jobs')

    from .main import bp as main_blueprint
    app.register_blueprint(main_blueprint)

    from .services import bp as services_blueprint
    app.register_blueprint(services_blueprint, url_prefix='/services')

    from .settings import bp as settings_blueprint
    app.register_blueprint(settings_blueprint, url_prefix='/settings')

    return app
